function s050610_debug_1d1g1sr_fast

  dbstop error
  
  fit_par = [];
  fit_par.verbose = 0;
  fit_par.debug   = 0;

  fit_par.min_iter = 10;
  fit_par.max_iter = 1000;
  
  fit_par.nsamples = 100;
  
  opt = optimset( @fminbnd );
  opt = optimset( opt, 'Display', 'off', 'MaxFunEvals', 40, 'MaxIter', 10, 'TolX', +Inf, 'TolFun', 1e-4 );
  fit_par.fminsearch_options = opt;
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Define a 1d1g1sr model
  % see compute_post_1d1g1sr for complete details
  
  model.b0 = 0.95;
  model.w0d = 0.13;
  model.gamma0 = 1.001;
  model.beta0  = 0.775;
  model.sigma1 = 1.7;
  model.V1     = 1.34;
  
  m = 100000;
  n = 1;
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Check that generate_1d1g1sr works
  
  data = generate_1d1g1sr( model, m, n );
  
  
  disp( mean( data(:) == 0 ) );
  disp( model.b0 * model.w0d );
  

  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Check that fit_1d1g1sr_fast works
  
  [ fit_model, misc ] = fit_1d1g1sr_fast( data, fit_par );
  
  disp( [ mfilename ': fit_model:' ] );
  disp( fit_model );
  
  disp( [ mfilename ': misc:' ] );
  disp( misc );
  
  
  figure; 
  [w,x] = hist( data(find(data>0)), 1000 );  
  w = w(:);
  x = x(:);
  w = w / sum( w ); 
  x = x(:);  w = w(:);
  set( bar( x, w), 'edgecolor', [ 0.7 0.7 0.7 ], 'facecolor', [ 0.7 0.7 0.7 ] );
  
  
  %  a_mat = [ [ model.b0 * model.w0d; zeros( numel( x(:) )-1,1) ],	    model.b0 * ( 1 - model.w0d ) * gampdf( model.gamma0, model.beta0, x(:) ),	    ( 1 - model.b0 ) * my_ricepdf( x(:), model.sigma1, model.V1 ) ];

  a_mat = [   model.b0 * ( 1 - model.w0d ) * gampdf( x(:), model.gamma0, model.beta0 ) ];
  a_mat( :,3 ) = 0;
  
  t0 = model.gamma0 * model.beta0;
  grt_ind = find( x > t0 );
  a_mat( grt_ind, 2 ) = ( 1 - model.b0 ) * my_ricepdf( x(grt_ind)-t0, model.sigma1, model.V1 );

  a_mat = [ sum( a_mat, 2 ),  a_mat ];
  
  a_mat = a_mat / sum( a_mat(:,1) );
  
  hold on; plot( x(:), a_mat, 'linewidth', 2 );

  
  a_mat = [   fit_model.b0 * ( 1 - fit_model.w0d ) * gampdf( x(:), fit_model.gamma0, fit_model.beta0 ) ];
  a_mat( :,3 ) = 0;
  
  t0 = fit_model.gamma0 * fit_model.beta0;
  grt_ind = find( x > t0 );
  a_mat( grt_ind, 2 ) = ( 1 - fit_model.b0 ) * my_ricepdf( x(grt_ind)-t0, fit_model.sigma1, fit_model.V1 );

  a_mat = [ sum( a_mat, 2 ),  a_mat ];
  
  a_mat = a_mat / sum( a_mat(:,1) );
  
  hold on; plot( x(:), a_mat, '--', 'linewidth', 2 );

    
    
  % ( 2 ) Log domain
  
  
  % show the data
  
  figure; 
  [w,x] = hist( log(data(find(data>0))), 1000 );  
  w = w(:);
  x = x(:);
  w = w / sum( w ); 
  x = x(:);  w = w(:);
  set( bar( x, w), 'edgecolor', [ 0.7 0.7 0.7 ], 'facecolor', [ 0.7 0.7 0.7 ] );
  
  % Show the true distribution 

  a_mat = [   model.b0 * ( 1 - model.w0d ) * exp(x(:)) .* gampdf( exp(x(:)), model.gamma0, model.beta0 ) ];
  a_mat( :,3 ) = 0;
  
  t0 = model.gamma0 * model.beta0;
  grt_ind = find( exp(x) > t0 );
  a_mat( grt_ind, 2 ) = exp(x(grt_ind)) .* ( 1 - model.b0 ) .* my_ricepdf( exp(x(grt_ind))-t0, model.sigma1, model.V1  );

  a_mat = [ sum( a_mat, 2 ),  a_mat ];
  a_mat = a_mat / sum( a_mat(:,1) );
  
  hold on; plot( x(:), a_mat, 'linewidth', 2 );


  % Show the estimated distribution
  
  a_mat = [   fit_model.b0 * ( 1 - fit_model.w0d ) * exp(x(:)) .* gampdf( exp(x(:)), fit_model.gamma0, fit_model.beta0 ) ];
  a_mat( :,3 ) = 0;
  
  t0 = fit_model.gamma0 * fit_model.beta0;
  grt_ind = find( exp(x) > t0 );
  a_mat( grt_ind, 2 ) = exp(x(grt_ind)) .* ( 1 - fit_model.b0 ) .* my_ricepdf( exp(x(grt_ind))-t0, fit_model.sigma1, fit_model.V1 );

  a_mat = [ sum( a_mat, 2 ),  a_mat ];
  
  a_mat = a_mat / sum( a_mat(:,1) );
  
  hold on; plot( x(:), a_mat, '--', 'linewidth', 2 );


  keyboard;
  
  