function s060307_extract_video( basedir, recording_list )
  
  if nargin < 2
    error( [ mfilename ' needs 2 input argument.' ] );
  end
  
  n_rec = numel( recording_list );
  
  for a = 1:n_rec
    
    % Process the 3 cameras, one after another
    
    recording_name = recording_list{ a };
    
    for cam = 1:3
      
      disp( ' ' );
      
      par = [];
      
      par.resolution = [ 24 32 ];
      
      par.out_filename = sprintf( '/home/speech/lathoud/FEATURES/avcalib/%s/%s_cam%d_video_motion2_%02d_%02d.mat', recording_name, recording_name, cam, par.resolution );
      
      % If the output file already exists, then skip it
      
      if exist( par.out_filename, 'file' )
	
	disp( [ mfilename ': output file already exists. Skipping it.' ] );
	disp( [ '  "' par.out_filename '"' ] );

      else
	
	disp( [ mfilename ': starting processing a video. The output file will be:' ] );
	disp( [ '  "' par.out_filename '"' ] );
	
	% Create it to lock it from other computers
	
	fid = fopen( par.out_filename, 'wt' );
	fclose( fid );
	
	% Do the processing
	
	par.binary_mask = zeros( 288, 360 );
	par.binary_mask( 5:288, 6:356 ) = 1;
	par.in_filename_template = sprintf( '/home/speech/lathoud/FEATURES/avcalib/%s/ppm_cam%d/image*.ppm', recording_name, cam );
	par.in_filename_regexp = 'image(\d+).ppm';
	
	a_dir = '/home/speech/lathoud/2005-10-11-MMM-BACKUP/Lathoud/av16.3_v6';
	addpath( a_dir );
	o = seq_av163( recording_name, a_dir );

	par.frame1_timestamp = o.cam(1).frame1_timestamp;
	
	par.interval_sec = 1 / 25;
	
	
	s060223_extract_motion2( par );
	
      end

    end % Loop through three cameras

    
    
  end % Loop through AV16.3 recordings